@@ -20,7 +20,7 @@ class BadToken(InvalidToken):
 class AccountAPI(API):
     """ Interacts with OCS Account API.
     """
-    base_url = 'http://localhost:5004'
+    base_url = 'https://account.cloud.online.net/'
 
     def perm_matches(self, request_perm, effective_perm):
         """ Evaluates whether `request_perm` is granted by `effective_perm`.
