@@ -3,4 +3,4 @@ from . import API
 
 class ComputeAPI(API):
 
-    base_url = 'http://localhost:5002'
+    base_url = 'https://api.cloud.online.net'
